@@ -22,10 +22,7 @@ test_that("Errors are thrown when calling countna", {
 
     avfilt <- avfilttest
     avfilt[[1]]$strand[which(avfilt[[1]]$strand == '+')] <- "toto"
-    expm <- paste0("\n\t In .computeecdf or countna, strand is neither plus or",
-            " minus in the table returned by the function ",
-            "averageandfilterexprs. This should not happen. Contact the ",
-            "developer.\n")
+    expm <- "Invalid strand value"
     expect_error(countna(avfilt, expdf, verbose = FALSE), regexp = expm)
 
     avfilt <- avfilttest
@@ -33,8 +30,6 @@ test_that("Errors are thrown when calling countna", {
         "ctrl_rep1.plus_score"] <- NA
     avfilt[[1]][which(avfilt[[1]]$gene == "AP5S1")[c(1,2)],
         "ctrl_rep2.plus_score"] <- NA
-    expm <- paste0("\n\t Number of NA is different between conditions for ",
-              "AP5S1: 10 - 8",
-              ". This should not happen. Contact the developer.\n")
+    expm <- "NA count mismatch between conditions"
     expect_error(countna(avfilt, expdf, verbose = FALSE), regexp = expm)
 })
