@@ -9,7 +9,7 @@ transdf <- read.delim(transpath, header = FALSE)
 avfilt <- averageandfilterexprs(expdf, transdf, expthres,
         showtime = FALSE, verbose = FALSE)
 rescountna <- countna(avfilt, expdf, nbcpu = 1, verbose = FALSE)
-ecdf <- genesECDF(avfilt, expdf, verbose = FALSE)
+ecdf <- genesECDF(avfilt, verbose = FALSE)
 resecdf <- ecdf[[1]]
 nbwindows <- ecdf[[2]]
 resmeandiff <- meandifference(resecdf, expdf, nbwindows,
